#
# spec file for package owncloud-complete-files
#
# Copyright (c) 2012-2020 ownCloud, Inc.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes, issues or comments via http://github.com/owncloud/
#

# name used as apache alias and topdir for php code.
%define owncloud	owncloud

# CAUTION: keep in sync with debian.rules

#ask fedora buils system not to mangle shebangs, breaks file signatures
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
%undefine __brp_mangle_shebangs
%endif

### apache variables
%if 0%{?suse_version}
%define apache_serverroot	/srv/www/htdocs
%define apache_confdir /etc/apache2/conf.d
%define oc_user wwwrun
%define oc_group www
%define oc_user_id 30
%define oc_group_id 8
%else
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
%define apache_serverroot	/var/www/html
%define apache_confdir /etc/httpd/conf.d
%define oc_user apache
%define oc_group apache
%define oc_user_id 48
%define oc_group_id 48
%else
%error "Unknown platform"
%endif
%endif

# CAUTION: keep in sync with debian.rules
%define oc_dir		%{apache_serverroot}/%{owncloud}
%define oc_config_dir 	%{oc_dir}/config
%define oc_data_dir 	%{oc_dir}/data
%define oc_apps_external_dir %{oc_dir}/apps-external
%define oc_data_pdir 	%{oc_dir}

Name:           owncloud-complete-files

## define prerelease % nil, if this is *not* a prerelease. Caution: always lower case beta rc.
%define prerelease %nil
%define base_version 10.7.0

%if 0%{?centos_version} == 600 || 0%{?fedora_version} || "%{prerelease}" == ""
# For beta and rc versions we use the ~ notation, as documented in
# http://en.opensuse.org/openSUSE:Package_naming_guidelines
Version:       	%{base_version}
%if "%{prerelease}" == ""
Release:        2.1
%else
Release:       	0.2.1.%{prerelease}
%endif
%else
Version:       	%{base_version}~%{prerelease}
Release:        2.1
%endif

# http://download.owncloud.org/community/testing/owncloud-8.2.2RC1.tar.bz2
# https://download.owncloud.org/community/owncloud-complete-20200731.tar.bz2
Source0:        owncloud-complete-20210326.tar.bz2 
Source1:        apache_conf_default
Source2:        README
Source5:	disable-updatechecker.config.php
Source6:	rpmlintrc
Url:            http://www.owncloud.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Summary:        The ownCloud Server Enterprise Edition - Private file sync and share server
License:        AGPL-3.0 and MIT
Group:          Productivity/Networking/Web/Utilities

%if 0%{?suse_version}
Recommends: %{name}-deps
%endif

%if "%{?_repository}" == "openSUSE_Tumbleweed"
# disable rpmlint for Tumbleweed while it is broken.
# It has random errors like these:
#  IOError: [Errno 2] No such file or directory: '/tmp/rpmlint.owncloud-ee-base-8.2.2-1.1.noarch.rpm.zFc3ft/usr/share/owncloud/apps/files_external/tests/env/stop-smb-silvershell.sh'

BuildRequires:        -rpmlint -rpmlint-mini

# useradd, groupadd is needed in pre section
PreReq: shadow
%endif

Obsoletes:	owncloud-files <= %{base_version}
Obsoletes:	owncloud-enterprise-files <= %{base_version}
Obsoletes:	owncloud-enterprise	<= 9.01.99
Obsoletes:	owncloud-enterprise-theme <= 9.01.99
Obsoletes:	owncloud-enterprise-app-files_antivirus	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-files_ldap_home	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-admin_audit	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-windows_network_drive	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-files_drop	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-files_sharing_log	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-enterprise_key	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-password_policy	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-user_shibboleth	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-firewall	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-sharepoint	<= 9.01.99
Obsoletes:	owncloud-enterprise-app-objectstore	<= 9.01.99

Obsoletes:	owncloud-server 	<= 9.01.99
Obsoletes:	owncloud-config-apache 	<= 9.01.99
Obsoletes:	owncloud		<= 9.01.99

%description
ownCloud Server Complete Edition provides you a private file sync and share
cloud. Host this server to easily sync business or private documents
across all your devices, and share those documents with other users of
your ownCloud server on their devices.

This package installs as follows:
oc_dir:        %{oc_dir}
oc_data_dir:   %{oc_data_dir}
oc_config_dir: %{oc_config_dir}

ownCloud - Your Cloud, Your Data, Your Way!  www.owncloud.org

#####################################################

%prep
%setup -q -n owncloud
cp %{SOURCE1} .
cp %{SOURCE2} .
#%%patch0 -p0

## remove .bower.json .bowerrc .gitattributes .gitmodules
# find . -name .bower\* -print -o -name .git\* -print | xargs -r rm -rf
## remove ~ backup files
# suse-filelist-forbidden-backup-file (Badness: 10000) apps/twofactor_totp/vendor/khanamiryan/qrcode-detector-decoder/tests/QrReaderTest.php~# is not allowed in SUSE, backup files (~, .swp or .bak) are not allowed
find . -name \*~ -print | xargs -r rm -f

%build
rm -f Jenkinsfile

%install
# We had silently skipped files under %{_docdir} on both SUSE and CentOS. Do not use that for our
# apache template. Prefer /usr/share/lib, it always installs flawlessly.
%define oc_docdir_base /usr/share/lib
%define oc_docdir %{oc_docdir_base}/%{name}-%{base_version}

# no server side java code contained, alarm is false
export NO_BRP_CHECK_BYTECODE_VERSION=true
idir=$RPM_BUILD_ROOT/%{oc_dir}
mkdir -p $RPM_BUILD_ROOT/%{oc_dir}
mkdir -p $RPM_BUILD_ROOT/%{oc_dir}/etc
mkdir -p $RPM_BUILD_ROOT/%{oc_data_dir}
mkdir -p $RPM_BUILD_ROOT/%{oc_config_dir}
mkdir -p $RPM_BUILD_ROOT/%{oc_dir}/core/skeleton
mkdir -p $RPM_BUILD_ROOT/%{oc_apps_external_dir}

cp -aRf .htaccess .user.ini * $idir
rm -f $idir/debian.*{install,rules,control}
rm -f $idir/README{,.SELinux,.packaging}
sed -e 's@/var/www/owncloud@%{oc_dir}@' < $idir/apache_conf_default > owncloud-config-apache.conf.default
rm -f $idir/apache_conf_default

mkdir -p $RPM_BUILD_ROOT/%{oc_docdir}
mv README owncloud-config-apache.conf.default $RPM_BUILD_ROOT/%{oc_docdir}

## https://github.com/owncloud/core/issues/22257
# disable-updatechecker.config.php
cp %{SOURCE5} $idir/config/

%clean
rm -rf "$RPM_BUILD_ROOT"

%pre
## create apache user and group, so that our files section works.
getent group  %{oc_group} > /dev/null || sh -x -c "groupadd -r -g %{oc_group_id} %{oc_group}"
getent passwd %{oc_user}  > /dev/null || sh -x -c "useradd  -r -u %{oc_user_id} -g %{oc_group} -c 'Dummy for %{name}' %{oc_user}"

%post
## Delete the apache user, if it was the one we created.
## Never delete the apache user, if apache server is installed.
test ! -d %{apache_confdir} && getent passwd %{oc_user} | grep -q "Dummy for %{name}" && sh -x -c "userdel %{oc_user}" || true

%files
%defattr(0644,root,root,0755)
%dir %{oc_docdir_base}
%dir %{oc_docdir}
%{oc_docdir}/*

# is there any security to be gained here? Easier to chown everthing to % {oc_user}
%defattr(0644,root,%{oc_group},0755)
%attr(0755,%{oc_user},%{oc_group}) %{oc_dir}/occ
%attr(0775,%{oc_user},%{oc_group}) %{oc_dir}/apps
%attr(0775,%{oc_user},%{oc_group}) %{oc_data_dir}
%attr(0775,%{oc_user},%{oc_group}) %{oc_config_dir}
%attr(0775,%{oc_user},%{oc_group}) %{oc_apps_external_dir}
# BUMMER: exclude excludes globally, not just below. It cannot be used to avoid duplicate warnings?
# FIXME: only cure against the duplicate warnings is a -f file-list

# https://github.com/owncloud/core/issues/23512
%attr(0755,%{oc_user},%{oc_group}) %{oc_dir}/.htaccess
%attr(0755,%{oc_user},%{oc_group}) %{oc_dir}/.user.ini
%dir %{oc_dir}
%{oc_dir}/*

%changelog
* Thu Apr 15 2021 Cristian Rodriguez  <crodriguez@owncloud.com>
- Update to version 10.7.0
* Fri Feb  5 2021 Cristian Rodriguez  <crodriguez@owncloud.com>
-  Update to version 10.6.0
* Thu Aug 13 2020 <jw@owncloud.com>
- Fix opensuse builds, where ~ files are forbidden.
- Removed bogus README contents.
- Renamed to owncloud-complete-files
  Tue Aug  4 22:20:08 -04 2020 - crodriguez@owncloud.com
- Update to version 10.5.0
  Thu Mar 12 22:30:30 -03 2020 - crodriguez@owncloud.com
- Update to version 10.4.0
  Fri Dec  6 21:07:11 -03 2019 - crodriguez@owncloud.com
- Update to version 10.3.2
  Thu Jul  4 00:20:20 -04 2019 - crodriguez@owncloud.com
- Update to version 10.2.1
  Fri May 31 11:15:00 -04 2019 - crodriguez@owncloud.com
- Update to version 10.2.0
  Sun Apr 14 22:43:26 -04 2019 - crodriguez@owncloud.com
- Update to version 10.1.1
  Mon Feb 25 12:06:14 -03 2019 - crodriguez@owncloud.com
- Update to version 10.1.0
  Tue Oct  9 16:36:02 -03 2018 - crodriguez@owncloud.com
- Update to version 10.0.10.1
  Fri Sep 28 12:49:15 -03 2018 - crodriguez@owncloud.com
- Update to version 10.0.10
  Thu Jul 19 11:51:50 -04 2018 - crodriguez@owncloud.com
- Update to version 10.0.9
  Fri May  4 11:10:06 -03 2018 - crodriguez@owncloud.com
- Update to version 10.0.8
  Wed Feb 21 12:54:49 -03 2018 - crodriguez@owncloud.com
- Update to version 10.0.7
  Fri Dec  8 12:59:52 -03 2017 - crodriguez@owncloud.com
- Update to version 10.0.4
  Thu Sep 28 10:15:46 -03 2017 - crodriguez@owncloud.com
- Update to version 10.0.3
  Tue May 30 20:44:06 -04 2017 - crodriguez@owncloud.com
- Update to version 10.0.2
  Wed May 24 17:06:58 -04 2017 - crodriguez@owncloud.com
- Update to version 10.0.2~rc1
  Mon May 22 18:11:29 -04 2017 - crodriguez@owncloud.com
- Update to version 10.0.1
  Mon May 22 11:58:25 -04 2017 - crodriguez@owncloud.com
- Update to version 10.0.1~rc5
  Mon May 22 10:23:37 -04 2017 - crodriguez@owncloud.com
- Update to version 10.0.1~rc4
  Fri May 19 18:10:05 -04 2017 - crodriguez@owncloud.com
- Update to version 10.0.1~rc3
  Thu May 18 19:08:29 -04 2017 - crodriguez@owncloud.com
- Update to version 10.0.1~rc2
  Tue May 16 17:37:28 -04 2017 - crodriguez@owncloud.com
- Update to version 10.0.1~rc1
  Mon Apr 24 17:06:53 -03 2017 - crodriguez@owncloud.com
- Update to version 10.0.0~rc4
  Thu Apr 20 16:48:06 -03 2017 - crodriguez@owncloud.com
- Update to version 10.0.0~rc2
  Wed Apr 19 11:27:28 -03 2017 - crodriguez@owncloud.com
- Update to version 10.0.0~rc1
  Mon Apr 10 12:23:10 -03 2017 - crodriguez@owncloud.com
- Update to version 10.0.0~beta2
  Tue Apr  4 00:04:36 -03 2017 - crodriguez@owncloud.com
- Update to version 10.0.0~beta
  Mon Apr  3 12:45:18 -03 2017 - crodriguez@owncloud.com
- Update to version 9.1.5~rc1
* Thu Feb 16 2017 crodriguez@owncloud.com
- Update to version 9.1.4
* Thu Jan 26 2017 crodriguez@owncloud.com
- Update to version 9.1.4~rc2
* Mon Dec 12 2016 crodriguez@owncloud.com
- Update to version 9.1.3
* Tue Nov 29 2016 crodriguez@owncloud.com
- Update to version 9.1.3~rc1
* Tue Nov  8 2016 crodriguez@owncloud.com
- Update to version 9.1.2
* Wed Oct 26 2016 crodriguez@owncloud.com
- Update to version 9.1.2~rc2
* Fri Oct 21 2016 crodriguez@owncloud.com
- Update to version 9.1.2~rc1
* Mon Sep 19 2016 crodriguez@owncloud.com
- Update to version 9.1.1
* Wed Sep 14 2016 jw@owncloud.com
- Update to version 9.1.1~rc3
* Mon Sep 12 2016 jw@owncloud.com
- Update to version 9.1.1~rc2
* Mon Aug 22 2016 crodriguez@owncloud.com
- Update to version 9.1.1~rc1
* Wed Jul 20 2016 jw@owncloud.com
- Update to version 9.1.0
* Mon Jul 18 2016 jw@owncloud.com
- Update to version 9.1.0~rc3
* Wed Jul 13 2016 jw@owncloud.com
- Update to version 9.1.0~rc2
* Wed Jun 29 2016 jw@owncloud.com
- Update to version 9.1.0~rc1
* Wed Jun 29 2016 jw@owncloud.com
- fix https://github.com/owncloud/core/issues/23512
* Wed Jun 29 2016 jw@owncloud.com
- Update to version 9.0.3
* Fri Jun 17 2016 jw@owncloud.com
- Update to version 9.0.3~rc1
* Wed May  4 2016 jw@owncloud.com
- Update to version 9.0.2
* Mon May  2 2016 jw@owncloud.com
- Update to version 9.0.2~rc2
* Wed Apr 27 2016 jw@owncloud.com
- Update to version 9.0.2~rc1
* Thu Apr  7 2016 jw@owncloud.com
- Update to version 9.0.1
* Mon Apr  4 2016 jw@owncloud.com
- Update to version 9.0.1~rc2
* Fri Apr  1 2016 jw@owncloud.com
- use lowercase rc1
* Tue Mar 29 2016 jw@owncloud.com
- Update to version 9.0.1~RC1
* Thu Mar 24 2016 jw@owncloud.com
- Update to version 9.0.1~beta
- fixed obsoletes
* Thu Mar 10 2016 jw@owncloud.com
- obsolete all enterprise-apps-* subpackages...
* Thu Mar 10 2016 jw@owncloud.com
- take care of user and group without breaking SUSE.
* Tue Mar  8 2016 jw@owncloud.com
- Upgrade to 9.0.0
* Mon Mar  7 2016 jw@owncloud.com
- Upgrade to 9.0.0~RC3
* Sat Mar  5 2016 jw@owncloud.com
- Upgrade to 9.0.0~RC2
* Thu Mar  3 2016 jw@owncloud.com
- retain dotfiles https://github.com/owncloud/core/issues/22803
* Thu Mar  3 2016 jw@owncloud.com
- fix https://github.com/owncloud/core/issues/22804
* Wed Mar  2 2016 jw@owncloud.com
- Upgrade to 9.0.0~RC1
* Wed Feb 24 2016 jw@owncloud.com
- obsoletes in spec changed to < 8.99.99
* Fri Feb 19 2016 jw@owncloud.com
- explicily added .user.ini file
  moved owncloud-config-apache.conf.default to %%doc
  so that we survive integrity checks.
* Fri Feb 19 2016 jw@owncloud.com
- ported to ee:9.0:testing/owncloud-enterprise-files
* Thu Feb 18 2016 jw@owncloud.com
- ported ce:9.0:testing/owncloud-files to ee:8.2:testing/owncloud-enterprise-files
* Tue Feb 16 2016 jw@owncloud.com
- apps, data, config directories had no x-bits
* Fri Feb 12 2016 jw@owncloud.com
- added disable-updatechecker.config.php -- this is the correct solution for
  https://github.com/owncloud/core/issues/22257
* Fri Feb 12 2016 jw@owncloud.com
- help https://github.com/owncloud/core/issues/22257
* Thu Feb 11 2016 jw@owncloud.com
- survive bad broken rpmlint on openSUSE_Tumbleweed
* Thu Feb 11 2016 jw@owncloud.com
- initial 9.0 setup: owncloud-enterprise-files
- must not include .gitkeep or .gitignore files.
* Thu Feb  4 2016 jw@owncloud.com
- made file system layout compatible with tar/zip installations,
  preparing for owncloud-deps sub-package.
* Tue Dec 22 2015 jw@owncloud.com
- Updated to 8.2.2
* Wed Dec 16 2015 jw@owncloud.com
- Updated to 8.2.2~RC1
* Fri Dec  4 2015 jw@owncloud.com
- typo in etc/owncloud-config-apache.conf.default fixed.
  Thanks JP.
* Thu Dec  3 2015 jw@owncloud.com
- New package: owncloud-ee-base without dependencies.
- Replaces, Conflicts, Obsoletes all other owncloud-* packages << 8.2.2
- improved apache_config_default
- dropped htaccess re-added.
* Tue Nov 17 2015 jenkins@owncloud.com
- Update to version 8.2.1
* Tue Nov 17 2015 jenkins@owncloud.com
- Update to version 8.2.1~RC4
* Fri Nov 13 2015 jw@owncloud.com
- Update to version 8.2.1~RC3
- added app-password_policy subpackage
* Wed Nov 11 2015 jenkins@owncloud.com
- Update to version 8.2.1~RC2
* Wed Nov  4 2015 jw@owncloud.com
- Update to version 8.2.1~RC1
* Fri Sep 18 2015 jw@owncloud.com
- Update to version 8.2~beta1
* Mon Sep 14 2015 jw@owncloud.com
- Require owncloud-server, instead of a virtual owncloud-enterprise-server.
* Fri Sep 11 2015 jw@owncloud.com
- Update to version 8.1.3
* Fri Sep  4 2015 jw@owncloud.com
- Updated ownCloudServerAdminManual.pdf
* Wed Sep  2 2015 jw@owncloud.com
- Update to version 8.1.2
* Sun Aug 30 2015 jw@owncloud.com
- Update to version 8.1.2~RC1
* Fri Aug 14 2015 jw@owncloud.com
- softwarecollections rh-scl have renamed their packages: rh-php56-php
* Sat Aug  8 2015 jw@owncloud.com
- Update to version 8.1.1
* Sat Aug  8 2015 jw@owncloud.com
- RPM: Do not hard require mysql locally. That is not realistic for enterprise.
  DEB does not have that requirement anyway.
- Using %%{ocphp} to select the correct php version.
- fixed https://github.com/owncloud/core/issues/16132
- Updated ownCloudServerAdminManual.pdf
* Mon Aug  3 2015 jw@owncloud.com
- Update to version 8.1.1~RC1
* Fri Jul 24 2015 jw@owncloud.com
- Update to version 8.1.1~beta1
* Mon Jul 13 2015 jw@owncloud.com
- Updated ownCloudServerAdminManual.pdf
* Fri Jul  3 2015 jw@owncloud.com
- Update to version 8.1.0
* Wed Jul  1 2015 jw@owncloud.com
- Version number patched back to 3 digits 8.1.0~RC2
* Wed Jul  1 2015 jw@ownCloud.com
- Update to version 8.1~RC2
* Tue Jun  2 2015 jw@owncloud.com
- fixed https://github.com/owncloud/core/issues/16132
* Tue May 19 2015 jw@owncloud.com
- Updated to 8.1.0~Beta2
* Mon May 11 2015 jw@owncloud.com
- https://github.com/owncloud/core/issues/16204
  Fix install on CentOS_6@SCL-PHP54
* Fri May  8 2015 jw@owncloud.com
- Updated to 8.1.0~Beta1
* Thu Apr 23 2015 jw@owncloud.com
- Updated to 8.1.0~Alpha2
  - Added app: files_drop
  - Removed app: search_elastic
* Thu Apr 16 2015 jw@owncloud.com
- Updated to 8.1.0~Alpha1
  - Added app: search_elastic
* Thu Apr 16 2015 jw@owncloud.com
- Update to 8.0.3 RC2
* Sat Mar 28 2015 jw@owncloud.com
- Release  "8.0.3" April 6. 2015
  - Fix several Constrain Violation Exceptions
  - Fix misleading Maintenance mode message
  - Timezone fixes for countries with .05 and 0.75 offsets
  - Fix usage of default share folder location
  - Improved MSSQL compatibility
  - Reenable trashbin after failed rename
  - Fix disabling of APCu
  - Do not show update notification on mobile
  - Fix "Only variables should be passed by reference" error log spam
  - Add timeout to curl
  - Makes repair errors and warnings visible for the user when
  - Upgrading on the command line or in the web UI
  - Cron shall not operate in case we are in maintenance mode
  - Disable the cache updater when doing the encryption migration
  - Fix "Error while updating app" error
  - Internal Server Error after attempting to do "occ files:scan"
* Mon Mar 16 2015 jw@owncloud.com
- update to 8.0.2
- https://github.com/owncloud/enterprise/issues/560
  * Preinstall check for duplicate installations done.
  * Migration instructions in README.symlink done.
  * adopted the DEB upgrade detection algorithm for RPM.
- https://github.com/owncloud/enterprise/issues/573
  * fixed also for debian: virtual Provides did not work with versioned Depends.
* Thu Mar  5 2015 jw@owncloud.com
- removed ownCloudUserManual.pdf here to avoid a file conflict with owncloud-server
* Thu Mar  5 2015 jw@owncloud.com
- updated to 8.0.1 Mar 4, 22:41h
* Wed Mar  4 2015 jw@owncloud.com
- Updated to todays rebuild of 8.0.1 tar ball.
  Added latest Server and User PDFs.
* Wed Mar  4 2015 jw@owncloud.com
  * Fixing https://github.com/owncloud/enterprise/issues/552
  better. Do not Require clamav for CentOS and friends.
  Recommend for openSUSE. Describe the dependency of files_antivirus in the README.
* Tue Mar  3 2015 jw@owncloud.com
- fixed https://github.com/owncloud/enterprise/issues/552
  clamav was the last one missing
- fixed https://github.com/owncloud/enterprise/issues/549
  multiple missing dependencies added. We are now more on the side that build or
  install fails instead of manual post processing.
* Mon Mar  2 2015 jw@owncloud.com
- updated firewall app.
* Mon Mar  2 2015 jw@owncloud.com
- Match permissions on owncloud, data, themes, config, apps folders
  (they exist in both, owncloud and owncloud-enterprise* packages.)
  CentOS-7 is extremely picky: User, group, and modes must match exactly.
* Mon Mar  2 2015 jw@owncloud.com
- update to 8.0.1
  ownCloud app files_drop no longer included.
  ownCloud app search_elastic dropped.
* Wed Feb 18 2015 jw@owncloud.com
- enterprise version need not be exaclty the same as server version
* Tue Feb 17 2015 jw@owncloud.com
- updated to 8.0.0 RC2
* Sat Feb  7 2015 jw@owncloud.com
- Require owncloud-server-core instead of owncloud-server
* Mon Feb  2 2015 jw@owncloud.com
- updated to 8.0.0 RC1
* Fri Jan 30 2015 jw@owncloud.com
- make apps directory writable by oc_user
* Thu Jan 29 2015 jw@owncloud.com
- added all the RHEL_6_PHP5* build targets.
* Thu Jan 29 2015 jw@owncloud.com
- owncloud-enterprise-theme must not be build dependency, but must be
  a runtime dependency for owncloud-enterprise. Exception to the rule!
- generated deb metafiles for all subpackages with
  obs_check_deb_spec.sh
* Thu Jan 29 2015 jw@owncloud.com
- first completed specfile.
- fixed garbage filter .bower and .git .
- opensuse needs dir entries in %%files for top and top/apps,
  all others dont.
* Wed Jan 28 2015 jw@owncloud.com
- adapted isv:ownCloud:community:8.0/owncloud/owncloud.spec
  to become owncloud-enterprise.spec here.
- removed all unnecessary packages, that are now subpackages here.
* Thu Jan  8 2015 jw@owncloud.com
- initial draught for ownCloud 8
